/*
	Copyright (c) 2001 Alex Izvorski (USB autodetect)

	You may distribute and/or use for any purpose modified or unmodified
	copies of this software if you preserve the copyright notice above.

	THIS SOFTWARE IS PROVIDED AS IS AND COME WITH NO WARRANTY OF ANY
	KIND, EITHER EXPRESSED OR IMPLIED.  IN NO EVENT WILL THE
	COPYRIGHT HOLDER BE LIABLE FOR ANY DAMAGES RESULTING FROM THE
	USE OF THIS SOFTWARE.
*/


#ifdef HAVE_USB_H

typedef struct {
  int vendor_id;
  int product_id;
  char* vendor_name;
  char* product_name;
} usb_camera_info;

/*
  The information about vendor and product ids comes from 
    1) the gphoto2 sierra driver code (http://www.gphoto.org/) and 
    2) the list found at http://www.linux-usb.org/usb.ids
    
  It is very incomplete (and probably wrong) with respect to the cameras
  actually supported by photopc.
  
  If you have a camera that works but shows up as "Unknown Device", please
  send the vendor ID, product ID, and description to imaging@math.ualberta.ca
 */

static usb_camera_info usb_camera_table[] = {

// definitely(?) supported

{ 0x07b4, 0x0100, "Olympus Optical Co., Ltd.", "C-2100/C3000/C3040 Camera" },
{ 0x07b4, 0x0105, "Olympus Optical Co., Ltd.", "C-2040Z Camera" },
{ 0x07b4, -1, "Olympus Optical Co., Ltd.", "Unknown Device" },

{ 0x04b0, 0x0102, "Nikon Corp.", "Nikon Coolpix 990" },
{ 0x04b0, 0x0103, "Nikon Corp.", "Nikon Coolpix 880" },
{ 0x04b0, 0x0104, "Nikon Corp.", "Nikon Coolpix 995" }, // USB does not work
{ 0x04b0, 0x0106, "Nikon Corp.", "Nikon Coolpix 775" },
{ 0x04b0, -1, "Nikon Corp.", "Unknown Device" },

{ 0x06bd, 0x0403, "AGFA-Gevaert NV", "ePhoto CL18 Camera" },
{ 0x06bd, 0x0404, "AGFA-Gevaert NV", "ePhoto CL20 Camera" },
{ 0x06bd, -1, "AGFA-Gevaert NV", "Unknown Device" },

{ 0x1132, 0x4331, "Toshiba Corp., Digital Media Equipment", "PDR-M4/M5 Digital Camera" },
{ 0x1132, -1, "Toshiba Corp., Digital Media Equipment", "Unknown Device" },

{ 0x0874, 0x0100, "Vivitar Inc.", "ViviCam 2655" },
{ 0x0874, -1, "Vivitar Inc.", "Unknown Device" },

{ 0x04b8, 0x0403, "Epson Corp.", "Epson PhotoPC 3000z" },
{ 0x04b8, -1, "Epson Corp.", "Unknown Device" },

{ 0x0474, -1, "Sanyo Electric Co. Ltd.", "Unknown Device" },

{ 0x0546, -1, "Polaroid Corp.", "Unknown Device" },

{ 0x0636, -1, "Sierra Imaging, Inc.", "Unknown Device" },

// other cameras that probably don't work

{ 0x03f0, 0x0102, "Hewlett-Packard", "PhotoSmart S20" },
{ 0x03f0, 0x0202, "Hewlett-Packard", "PhotoSmart S20" },
{ 0x03f0, 0x4102, "Hewlett-Packard", "PhotoSmart 618 Camera" },
{ 0x03f0, 0x6202, "Hewlett-Packard", "PhotoSmart 215 Camera" },
{ 0x040a, 0x0001, "Kodak Co.", "DVC-323" },
{ 0x040a, 0x0002, "Kodak Co.", "DVC-325" },
{ 0x040a, 0x0100, "Kodak Co.", "DC-220" },
{ 0x040a, 0x0110, "Kodak Co.", "DC-260" },
{ 0x040a, 0x0111, "Kodak Co.", "DC-265" },
{ 0x040a, 0x0112, "Kodak Co.", "DC-290" },
{ 0x040a, 0x0120, "Kodak Co.", "DC-240" },
{ 0x040a, 0x0121, "Kodak Co.", "DC-240 (PTP firmware)" },
{ 0x040a, 0x0130, "Kodak Co.", "DC-280" },
{ 0x040a, 0x0131, "Kodak Co.", "DC-5000" },
{ 0x040a, 0x0132, "Kodak Co.", "DC-3400" },
{ 0x040a, 0x0140, "Kodak Co.", "DC-4800" },
{ 0x040a, 0x0300, "Kodak Co.", "EZ-200" },
{ 0x040a, 0x0400, "Kodak Co.", "MC3" },
{ 0x04a9, 0x3041, "Canon Inc.", "PowerShot S10" },
{ 0x04a9, 0x3043, "Canon Inc.", "PowerShot S20" },
{ 0x04a9, 0x3045, "Canon Inc.", "PowerShot S100" },
{ 0x04a9, 0x3047, "Canon Inc.", "Digital IXUS" },
{ 0x04a9, 0x3048, "Canon Inc.", "PowerShot G1" },
{ 0x04a9, 0x3049, "Canon Inc.", "PowerShot Pro90 IS" },
{ 0x04a9, 0x304b, "Canon Inc.", "IXY Digital 300" },
{ 0x04a9, 0x304e, "Canon Inc.", "PowerShot A20" },
{ 0x04c8, 0x0720, "Konica Corp.", "Digital Color Camera" },
{ 0x04cb, 0x0100, "Fuji Photo Film Co., Ltd.", "FinePix 1300 / 1400 / 4700 Zoom digital camrea" },
{ 0x04cb, 0x0103, "Fuji Photo Film Co., Ltd.", "FinePix NX-700 printer" },
{ 0x054c, 0x0010, "Sony Corp.", "DSC-S30/S70/S75/F505V/F505/FD92 Cybershot/Mavica Digital Camera" },
{ 0x054c, 0x0024, "Sony Corp.", "Mavica CD-1000 Camera" },
{ 0x05ca, 0x0101, "Ricoh Company Ltd.", "RDC-5300 Digital Camera" },
{ 0x05ca, 0x2201, "Ricoh Company Ltd.", "RDC-7 Digital Camera" },
{ 0x07cf, 0x1001, "Casio Computer Co., Ltd.", "QV-8000SX/3000EX Digicam" },

// webcames, etc that probably don't work

{ 0x03e8, 0x0004, "AOX Inc.", "SE401 WebCam" },
{ 0x0461, 0x0813, "Primax Electronics", "IBM UltraPort Camera" },
{ 0x046d, 0x0801, "Logitech Inc.", "QuickCam Home" },
{ 0x046d, 0x0810, "Logitech Inc.", "QuickCam Pro" },
{ 0x046d, 0x0840, "Logitech Inc.", "QuickCam Express" },
{ 0x046d, 0x0850, "Logitech Inc.", "QuickCam Web" },
{ 0x046d, 0xd001, "Logitech Inc.", "QuickCam Pro" },
{ 0x0471, 0x0302, "Philips", "PCA645VC WebCam" },
{ 0x0471, 0x0303, "Philips", "PCA646VC WebCam" },
{ 0x0471, 0x0307, "Philips", "PCVC675K WebCam" },
{ 0x0471, 0x0308, "Philips", "PCVC680K WebCam" },
{ 0x0471, 0x0311, "Philips", "PCVC740K ToUcam Pro" },
{ 0x0478, 0x0001, "Connectix Corp.", "QuickCam" },
{ 0x047d, 0x5002, "Kensington", "VideoCam CABO II" },
{ 0x047d, 0x5003, "Kensington", "VideoCam" },
{ 0x04f1, 0x0001, "Victor Company of Japan (JVC)", "GC-QX3 Digital Still Camera" },
{ 0x0502, 0xd001, "Acer, Inc.", "Divio NW801 Digital Camera" },
{ 0x0545, 0x8002, "Xirlink, Inc.", "IBM NetCamera" },
{ 0x0545, 0x8080, "Xirlink, Inc.", "IBM C-It WebCam" },
{ 0x0553, 0x0002, "VLSI Vision Ltd.", "CPiA WebCam" },
{ 0x0553, 0x0202, "VLSI Vision Ltd.", "Aiptek PenCam 1" },
{ 0x055f, 0xa800, "Mustek Systems Inc.", "MDC 800 Camera" },
{ 0x0572, 0x0001, "Conexant Systems (Rockwell), Inc.", "Ezcam II WebCam" },
{ 0x0573, 0x2000, "Nogatech Ltd.", "X10 va10a Wireless Camera" },
{ 0x05a9, 0x0511, "OmniVision Technologies, Inc.", "OV511 WebCam" },
{ 0x05a9, 0xa511, "OmniVision Technologies, Inc.", "OV511+ WebCam" },
{ 0x0602, 0x1001, "Vista Imaging Inc.", "ViCam WebCam" },
{ 0x069a, 0x0001, "Askey Computer Corp.", "VC010 WebCam [philips]" },
{ 0x06a5, 0xd001, "Divio", "ProLink DS3303u WebCam" },
{ 0x06cf, 0x1010, "SpheronVR AG", "PanoCam 10" },
{ 0x06cf, 0x1012, "SpheronVR AG", "PanoCam 12/12X" },
{ 0x0733, 0x0401, "ViewQuest Technologies, Inc.", "CS330 WebCam" },
{ 0x0733, 0x0402, "ViewQuest Technologies, Inc.", "M-318B WebCam" },
{ 0x0733, 0x0430, "ViewQuest Technologies, Inc.", "Intel Pro Share WebCam" },
{ 0x084d, 0x0003, "Minton Optic Industry Co., Inc.", "S-Cam F5 Digital Camera" },
{ 0x1046, 0x9967, "Winbond Electronics Corp. [hex]", "W9967CF/W9968CF WebCam IC" },

{ 0, 0, "", "" }

  };

#endif
